@@ -10,7 +10,7 @@ use PYX qw(char comment);
 use PYX::Parser;
 use PYX::Utils;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -18,7 +18,7 @@ sub new {
 	my $self = bless {}, $class;
 
 	# Output encoding.
-	$self->{'output_encoding'} = 'UTF-8';
+	$self->{'output_encoding'} = 'utf-8';
 
 	# Output handler.
 	$self->{'output_handler'} = \*STDOUT;
@@ -28,6 +28,7 @@ sub new {
 
 	# PYX::Parser object.
 	$self->{'pyx_parser'} = PYX::Parser->new(
+		'output_encoding' => $self->{'output_encoding'},
 		'output_handler' => $self->{'output_handler'},
 		'output_rewrite' => 1,
 		'callbacks' => {
@@ -46,24 +47,34 @@ sub new {
 # Parse pyx text or array of pyx text.
 sub parse {
 	my ($self, $pyx, $out) = @_;
+
 	$self->{'pyx_parser'}->parse($pyx, $out);
+
+	return;
 }
 
 # Parse file with pyx text.
 sub parse_file {
 	my ($self, $file, $out) = @_;
+
 	$self->{'pyx_parser'}->parse_file($file, $out);
+
+	return;
 }
 
 # Parse from handler.
 sub parse_handler {
 	my ($self, $input_file_handler, $out) = @_;
+
 	$self->{'pyx_parser'}->parse_handler($input_file_handler, $out);
+
+	return;
 }
 
 # Process data.
 sub _data {
 	my ($pyx_parser_obj, $data) = @_;
+
 	my $tmp = PYX::Utils::encode($data);
 	if ($tmp =~ /^[\s\n]*$/) {
 		return;
@@ -87,11 +98,14 @@ sub _data {
 		char($data),
 	);
 	print {$out} $encoded_output, "\n";
+
+	return;
 }
 
 # Process comment.
 sub _comment {
 	my ($pyx_parser_obj, $comment) = @_;
+
 	my $tmp = PYX::Utils::encode($comment);
 	if ($tmp =~ /^[\s\n]*$/) {
 		return;
@@ -105,6 +119,8 @@ sub _comment {
 		comment($comment),
 	);
 	print {$out} $encoded_output, "\n";
+
+	return;
 }
 
 1;
@@ -143,7 +159,7 @@ Returns instance of object.
 =item * C<output_encoding>
 
 Output encoding.
-Default value is 'UTF-8'.
+Default value is 'utf-8'.
 
 =item * C<output_handler>
 
@@ -272,6 +288,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
